- data
A matrix or data frame containing the variables. Columns not
specified by group_col, group_col2, or multilevel_col are assumed to be continuous
variables for analysis.
- group_col
A string specifying the first grouping column name that contains grouping
information. If group_col2 is not provided, it will be used for both
grouping and treatment.
- batch_col
A string specifying the column that identifies the batch or study for each sample.
- group_col2
A string specifying the second grouping column name. Default is
NULL.
- colors
A vector of splsda_colors for the groups or treatments. If
NULL, a random palette (using rainbow) is generated based on
the number of groups.
- pdf_title
A string specifying the file name for saving the PDF output.
If set to NULL, the function runs in IDE plots pane.
- ellipse
Logical. Whether to draw a 95\
Default is FALSE.
- bg
Logical. Whether to draw the prediction background in the figures.
Default is FALSE.
- var_num
Numeric. The number of variables to be used in the PLS-DA model.
- comp_num
Numeric. The number of components to calculate in the sPLS-DA model. Default is 2.
- scale
Character. Option for data transformation; if set to "log2", a log2
transformation is applied to the continuous variables. Default is NULL.
- cim
Logical. Whether to compute and plot the Clustered Image Map (CIM) heatmap. Default is FALSE.
- roc
Logical. Whether to compute and plot the ROC curve for the model.
Default is FALSE.
- verbose
A logical value indicating whether to print additional
informational output to the console. When TRUE, the function will
display progress messages, and intermediate results when
FALSE (the default), it runs quietly.