| cyt_ttest | R Documentation |
This function performs pairwise comparisons between two groups for each combination
of a categorical predictor (with exactly two levels) and a continuous outcome variable.
It first converts any character variables in data to factors and, if specified,
applies a log2 transformation to the continuous variables. Depending on the value of
scale, the function conducts either a two-sample t-test (if scale = "log2")
or a Mann-Whitney U test (if scale is NULL). The resulting p-values are printed
and returned.
cyt_ttest(data, scale = NULL, verbose = TRUE, format_output = FALSE)
data |
A matrix or data frame containing continuous and categorical variables. |
scale |
A character specifying a transformation for continuous variables.
Options are |
verbose |
A logical indicating whether to print the p-values of the statistical tests.
Default is |
format_output |
Logical. If TRUE, returns the results as a tidy data frame.
Default is |
If format_output is FALSE, returns a list of p-values (named by Outcome and Categorical variable).
If TRUE, returns a data frame in a tidy format.
Shubh Saraswat
data_df <- ExampleData1[, -c(3)]
data_df <- dplyr::filter(data_df, Group != "ND", Treatment != "Unstimulated")
# Test example
cyt_ttest(
data_df[, c(1:2, 5:6)],
scale = "log2",
verbose = TRUE,
format_output = TRUE
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.